import Head from 'next/head'
import { Footer } from '../components/Footer/Footer'
import { Navbar } from '../components/Navbar/Navbar'
import styles from '../styles/Home.module.css'
import Image from 'next/image'

export default function Home() {
    return (
        <div>
            <Head>
                <title>Palu-IoT - Laser Game</title>
                <meta name="description" content="Generated by create next app" />
                <link rel="icon" href="/favicon.ico" />
            </Head>

            <Navbar />
            <main className={styles.main}>
                <div className="container p-5 my-5 bg-light border-bottom">
                    <div class="col">
                        <h1 id="laser-game-by-palu-iot-inc">Laser Game by Palu-IoT, Inc</h1>
                        <p>Ce Laser Game est un l&#39;un des premiers basé sur le principe de l&#39;IoT.
                            Il est basé sur l&#39;idée de libre customisation des armes d&#39;une partie, mais a un faible coup grâce à l&#39;utilisation d&#39;ESP8266 comme base.
                            Ainsi, les composants internes peuvent varier pour permettre l&#39;utilisation d&#39;un meilleur laser ou d&#39;une photorésistance de moins bonne qualité ...
                            Mais aussi un choix beaucoup plus varier grâce à l&#39;impression 3D des boîtiers.</p>
                        <p>Le système utilise des WebSockets pour communiqué entre les participants et le serveur.</p>
                        <h2 id="installation">Installation</h2>
                        <h3 id="le-serveur-et-le-client">Le Serveur et le Client</h3>
                        <p>Téléchargé <a href="docker/">le dossier docker</a>.</p>
                        <p><em>WARNING</em> il faut que les ports 27017, 1235, 41848 soit disponible.</p>
                        <p>Installer docker et docker compose.
                            Ensuite, allez dans ce dossier, lancer le <a href="docker/docker-compose.yml">docker-compose</a> via la commande <code>sudo docker-compose up</code></p>
                        <h3 id="l-esp8266">L&#39;ESP8266</h3>
                        <h4 id="software">Software</h4>
                        <p>Pour installer l&#39;ESP8266, il faut d&#39;abord rendre l&#39;IDE Arduino capable de compilé pour l&#39;ESP.
                            Pour cela, je vous conseille ce petit tuto pour installer les bonnes dépendances :
                            <a href="http://blog.idleman.fr/programmer-un-esp8266-avec-arduino-ide-editor/">http://blog.idleman.fr/programmer-un-esp8266-avec-arduino-ide-editor/</a></p>
                        <p>Une fois fait, il va falloir télécharger la bibliothèque de WebSocket pour permettre la communication.
                            Pour utiliser cette bibliothèque, ouvrez le gestionnaire de bibliothèque dans l&#39;IDE Arduino et installez-le à partir de là.
                            Cherchez dans la barre de recherche <code>WebSockets</code> et installer celui de <code>Markus Sattler</code>.</p>
                        <p>Une fois fait, vous êtes presque prés à téléverser le code présent dans le dossier LaserGameV2 récupérable dans le dossier Arduino.
                            Avance cela n&#39;oublier pas de mettre le nom du wifi et le mot de passe dans le fichier <a href="Arduino/LaserGameV2/arduino_secrets.h">arduino_secrets.h</a> dans le dossier LaserGameV2.</p>
                        <p>Maintenant, on peut téléverser le code du fichier <a href="Arduino/LaserGameV2/LaserGameV2.ino">LaserGameV2</a> sur l&#39;ESP. Pour vérifier que toute fonction n&#39;hésité pas ouvrir le Moniteur de série sur la fréquence <code>115200</code>.</p>
                        <h4 id="hardware">Hardware</h4>
                        <p>Pour notre petit plat du jour, il va vous falloir : </p>
                        <ul>
                            <li>un Bouton</li>
                            <li>une Photoresistance</li>
                            <li>un Laser</li>
                            <li>une LED (Couleur et format au choix)</li>
                            <li>deux Resistance de 100 Ohms</li>
                            <li>un ESP8266 (Conseiller le <a href="https://www.amazon.fr/AZ-Delivery-NodeMCU-ESP8266-d%C3%A9veloppement-development/dp/B074Q27ZBQ">NodeMCU Lolin v3</a>)</li>
                            <li>Et beaucoups de cables !</li>
                        </ul>
                        <p>Maintenant, que l&#39;on a toutes nos pièces, il va falloir les assembler. Il y a 4 parties : </p>
                        <ul>
                            <li>Le bouton ou la trigger du pistolet</li>
                            <li>La Photoresistance qui fera office de capteur</li>
                            <li>Le Laser</li>
                            <li>La LED d&#39;affichage</li>
                        </ul>
                        <p><Image src="/Disposition%20des%20composant%202.png" alt="Disposition des composants" width="700" height="500" /></p>
                        <p>Et pour le montage voici un petit schéma de comment faire ! </p>
                        <p><Image src="/Disposition%20des%20composant%201.png" alt="Disposition des composants" width="700" height="500" /></p>
                        <p>Après, en fonction de vos composants, vous pouvez imprimer des boîtiers personnalisé</p>
                        <p>Nous rejetons toute responsabilité liée à l&#39;utilisation de matériel défectueux, en cas de triche ou de tentative de corruption.</p>

                    </div>
                </div>
            </main>
            <Footer />
        </div>
    )
}
